"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopNotification = exports.terminateNotifications = exports.initializeNotifications = exports.supportsNotifications = void 0;
const quick_lru_1 = require("quick-lru");
const uuid_1 = require("uuid");
const os = require("os");
function supportsNotifications() {
    if (process.platform !== 'win32') {
        return false;
    }
    const versionComponents = os.release().split('.');
    const majorVersion = parseInt(versionComponents[0], 10);
    // Only Windows 10 and newer are supported
    return majorVersion >= 10;
}
exports.supportsNotifications = supportsNotifications;
// The native binary will be loaded lazily to avoid any possible crash at start
// time, which are harder to trace.
let _nativeModule = undefined;
function getNativeModule() {
    if (_nativeModule !== undefined) {
        return _nativeModule;
    }
    _nativeModule = supportsNotifications()
        ? require('../../build/Release/desktop-notifications.node')
        : null;
    return _nativeModule;
}
/**
 * Initializes the desktop-notifications system.
 *
 * @param toastActivatorClsid CLSID used by Windows to report notification events
 */
function initializeNotifications(toastActivatorClsid) {
    var _a;
    (_a = getNativeModule()) === null || _a === void 0 ? void 0 : _a.initializeNotifications(toastActivatorClsid, onNotificationEvent);
}
exports.initializeNotifications = initializeNotifications;
/** Terminates the desktop-notifications system. */
function terminateNotifications() {
    var _a;
    (_a = getNativeModule()) === null || _a === void 0 ? void 0 : _a.terminateNotifications();
}
exports.terminateNotifications = terminateNotifications;
function showNotification(id, title, body) {
    var _a, _b;
    return (_b = (_a = getNativeModule()) === null || _a === void 0 ? void 0 : _a.showNotification(id, title, body)) !== null && _b !== void 0 ? _b : null;
}
function closeNotification(id) {
    var _a;
    return (_a = getNativeModule()) === null || _a === void 0 ? void 0 : _a.closeNotification(id);
}
const shownNotifications = new quick_lru_1.default({
    maxSize: 200,
});
function onNotificationEvent(event, id) {
    var _a;
    const notification = shownNotifications.get(id);
    if (notification === undefined) {
        // TODO: handle notifications that are not in the cache
        return;
    }
    if (event === 'click') {
        (_a = notification.onclick) === null || _a === void 0 ? void 0 : _a.call(notification);
    }
    // TODO: handle other events?
}
class DesktopNotification {
    constructor(title, body) {
        this.title = title;
        this.body = body;
        this.id = uuid_1.v4();
    }
    /** Shows the notification. */
    show() {
        shownNotifications.set(this.id, this);
        showNotification(this.id, this.title, this.body);
    }
    /** Closes the notification if it was ever shown. */
    close() {
        shownNotifications.delete(this.id);
        closeNotification(this.id);
    }
}
exports.DesktopNotification = DesktopNotification;
//# sourceMappingURL=desktop-notifications.js.map